==> anwiba-commons-lang-1.0.48-sources.jar: net/anwiba/commons/lang/identifier/Identifier.java <==
/*
 * #%L
 * anwiba commons core
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.lang.identifier;

import net.anwiba.commons.lang.hashable.AbstractHashable;

public class Identifier extends AbstractHashable implements IIdentifier {

  private static final long serialVersionUID = 9118818424031845777L;
  private final long value;

  public Identifier(final long value) {
    this.value = value;
  }

  @Override
  public long getValue() {
    return this.value;
  }

  @Override
  public boolean identical(final Object object) {
    if (!(object instanceof IIdentifier)) {
      return false;
    }
    final IIdentifier other = (IIdentifier) object;
    return this.value == other.getValue();
  }

  @Override
  public int hashValue() {
    return (int) (this.value ^ (this.value >>> 32));
  }
}

==> anwiba-commons-lang-1.1.121-sources.jar: net/anwiba/commons/lang/identifier/Identifier.java <==
/*
 * #%L
 * anwiba commons core
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.lang.identifier;

import net.anwiba.commons.lang.hashable.AbstractHashable;

public class Identifier extends AbstractHashable implements IIdentifier {

  private static final long serialVersionUID = 9118818424031845777L;
  private final long value;
  private final String scope;

  public Identifier(final long value, final String scope) {
    this.value = value;
    this.scope = scope;
  }

  @Override
  public String getNature() {
    return this.scope;
  }

  @Override
  public long getValue() {
    return this.value;
  }

  @Override
  public boolean identical(final Object object) {
    if (!(object instanceof IIdentifier)) {
      return false;
    }
    final IIdentifier other = (IIdentifier) object;
    return this.value == other.getValue();
  }

  @Override
  public int hashValue() {
    return (int) (this.value ^ (this.value >>> 32));
  }

  @Override
  public String toString() {
    return Long.toHexString(this.value);
  }
}
